package controllers

import (
	"eta/eta_mini_bridge/models"
	"eta/eta_mini_bridge/models/response"
	"eta/eta_mini_bridge/utils"

	"github.com/rdlucklib/rdluck_tools/paging"
)

type ChartController struct {
	BaseAuthController
}

// @Title List
// @Description create users
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Success 200 {object} models.BaseResponse
// @Failure 403 {object} models.BaseResponse
// @router /list [get]
func (this *ChartController) List() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")

	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize2
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = utils.StartIndex(currentIndex, pageSize)
	total, err := models.GetChartCount()
	if err != nil {
		br.Msg = "获取图表列表失败"
		br.ErrMsg = "获取图表列表失败，系统错误，Err:" + err.Error()
		return
	}
	chartList, err := models.GetChartList(startSize, pageSize)
	if err != nil {
		br.Msg = "获取图表列表失败"
		br.ErrMsg = "获取图表列表失败，系统错误，Err:" + err.Error()
		return
	}
	page := paging.GetPaging(currentIndex, pageSize, total)
	resp := new(response.ChartListResp)
	resp.List = chartList
	resp.Paging = page

	br.Ret = 200
	br.Msg = "获取图表列表成功"
	br.Success = true
	br.Data = resp

}
