package controllers

import "eta/eta_mini_bridge/models"

type ChartPermissionController struct {
	BaseAuthController
}

// List
// @Title 系统品种一级列表
// @Description 系统品种一级列表
// @Param   UserId   query   int  true       "角色ID"
// @Success 200 {object} models.LoginResp
// @router /list [get]
func (this *ChartPermissionController) List() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	items, err := models.GetChildChartPermissionListById(0)
	if err != nil {
		br.Msg = "权限列表获取失败"
		br.ErrMsg = "权限列表获取失败，系统错误，Err:" + err.Error()
		return
	}

	br.Ret = 200
	br.Data = items
	br.Msg = "列表获取成功"
	br.Success = true
}

// SecondList
// @Title 系统品种二级列表
// @Description 系统品种二级列表
// @Param   chartPermissonId   query   int  true       "品种ID"
// @Success 200 {object} []models.ChartPermission
// @router /second/list [get]
func (this *ChartPermissionController) SecondList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	id, _ := this.GetInt("chartPermissonId", 0)
	if id <= 0 {
		br.Msg = "品种id错误，获取失败"
		return
	}

	items, err := models.GetChildChartPermissionListById(id)
	if err != nil {
		br.Msg = "权限列表获取失败"
		br.ErrMsg = "权限列表获取失败，系统错误，Err:" + err.Error()
		return
	}

	br.Ret = 200
	br.Data = items
	br.Msg = "列表获取成功"
	br.Success = true
}

// AllList
// @Title 系统所有品种列表
// @Description 系统所有品种列表
// @Success 200 {object} []models.ChartPermission
// @router /allList [get]
func (this *ChartPermissionController) AllList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	items, err := models.GetChartPermissionList()
	if err != nil {
		br.Msg = "权限列表获取失败"
		br.ErrMsg = "权限列表获取失败，系统错误，Err:" + err.Error()
		return
	}

	br.Ret = 200
	br.Data = items
	br.Msg = "列表获取成功"
	br.Success = true
}
